@@ -137,6 +137,7 @@ from web3.types import (  # noqa: F401
     ABIEvent,
     ABIFunction,
     BlockIdentifier,
+    CallOverrideParams,
     EventData,
     FunctionIdentifier,
     LogReceipt,
@@ -639,7 +640,7 @@ class ContractConstructor:
 
         estimate_gas_transaction['data'] = self.data_in_transaction
 
-        return self.web3.eth.estimateGas(
+        return self.web3.eth.estimate_gas(
             estimate_gas_transaction, block_identifier=block_identifier
         )
 
@@ -897,7 +898,9 @@ class ContractFunction:
         self.arguments = merge_args_and_kwargs(self.abi, self.args, self.kwargs)
 
     def call(
-        self, transaction: Optional[TxParams] = None, block_identifier: BlockIdentifier = 'latest'
+        self, transaction: Optional[TxParams] = None,
+        block_identifier: BlockIdentifier = 'latest',
+        state_override: Optional[CallOverrideParams] = None,
     ) -> Any:
         """
         Execute a contract function call using the `eth_call` interface.
@@ -960,6 +963,7 @@ class ContractFunction:
             block_id,
             self.contract_abi,
             self.abi,
+            state_override,
             *self.args,
             **self.kwargs
         )
@@ -1160,9 +1164,9 @@ class ContractEvent:
                     raise e
                 else:
                     warnings.warn(
-                        f"The log with transaction hash: {log['transactionHash']} and "
+                        f"The log with transaction hash: {log['transactionHash']!r} and "
                         f"logIndex: {log['logIndex']} encountered the following error "
-                        f'during processing: {type(e).__name__}({e}). It has been discarded.'
+                        f"during processing: {type(e).__name__}({e}). It has been discarded."
                     )
                     continue
             yield rich_log
@@ -1334,7 +1338,7 @@ class ContractEvent:
             event_filter_params['blockHash'] = blockHash
 
         # Call JSON-RPC API
-        logs = self.web3.eth.getLogs(event_filter_params)
+        logs = self.web3.eth.get_logs(event_filter_params)
 
         # Convert raw binary data to Python proxy objects as described by ABI
         return tuple(get_event_data(self.web3.codec, abi, entry) for entry in logs)
@@ -1476,6 +1480,7 @@ def call_contract_function(
         block_id: Optional[BlockIdentifier] = None,
         contract_abi: Optional[ABI] = None,
         fn_abi: Optional[ABIFunction] = None,
+        state_override: Optional[CallOverrideParams] = None,
         *args: Any,
         **kwargs: Any) -> Any:
     """
@@ -1493,10 +1498,11 @@ def call_contract_function(
         fn_kwargs=kwargs,
     )
 
-    if block_id is None:
-        return_data = web3.eth.call(call_transaction)
-    else:
-        return_data = web3.eth.call(call_transaction, block_identifier=block_id)
+    return_data = web3.eth.call(
+        call_transaction,
+        block_identifier=block_id,
+        state_override=state_override,
+    )
 
     if fn_abi is None:
         fn_abi = find_matching_fn_abi(contract_abi, web3.codec, function_identifier, args, kwargs)
@@ -1518,12 +1524,8 @@ def call_contract_function(
             )
         else:
             msg = (
-                "Could not decode contract function call {} return data {} for "
-                "output_types {}".format(
-                    function_identifier,
-                    return_data,
-                    output_types
-                )
+                "Could not decode contract function call {function_identifier} "
+                "return data {return_data!r} for output_types {output_types}"
             )
         raise BadFunctionCallOutput(msg) from e
 
@@ -1615,7 +1617,7 @@ def estimate_gas_for_function(
         fn_kwargs=kwargs,
     )
 
-    return web3.eth.estimateGas(estimate_transaction, block_identifier)
+    return web3.eth.estimate_gas(estimate_transaction, block_identifier)
 
 
 def build_transaction_for_function(
